@@ -10,10 +10,12 @@
 #
 # ToDo: output final statistics
 # version
-#  2009-07-29 numfiles=  6 bad= 3  sumchars=  269 bad= 13  5% tmp09 jocr
-#  2010-08-09 numfiles= 10 bad= 0  sumchars= 1203 bad=  0  0% tmp09
+#  2009-07-29 numfiles=  6 bad= 3  sumchars=  269 bad= 13  5.20% tmp09 jocr
+#  2010-08-09 numfiles= 10 bad= 0  sumchars= 1203 bad=  0  0.00% tmp09
 #  2010-09-24 numfiles= 17 bad= 0  sumchars= 1665 bad=  0  0.00% tmp09-10
 #  2010-09-24 numfiles= 26 bad= 5  sumchars= 4671 bad= 58  1.24% tmp08-10
+#  2010-10-10 numfiles= 35 bad= 3  sumchars= 5919 bad= 19  0.32% tmp08-10+ex
+#  latest test: ./jocr/bin/gocr_chk.sh tmp08 tmp09 tmp10 jocr/examples/
 #
 GOCR=gocr
 numfiles=0      # number of checked files
@@ -59,8 +61,9 @@ for tfile in $(eval "find $dirs $filter | xargs"); do
     #      -u=unified_output_format --=divide_options_from_arguments
     #    return=$?: 0=same 1=differ
     # alternatives: cmp(bytewise diff),sdiff
-    ${GOCR} ${ifile} > $tmpdir/out
-    if diff -b -- ${tfile} $tmpdir/out >/dev/null; then
+    # redirect error channel to avoid pngtopnm xscale-warnings
+    ${GOCR} ${ifile} > $tmpdir/out 2>/dev/null
+    if diff -B -b -- ${tfile} $tmpdir/out >/dev/null; then
       numgood=$(($numgood+1))
       x=0
     else
