@@ -1,6 +1,6 @@
 /*
 This is a Optical-Character-Recognition program
-Copyright (C) 2000-2010  Joerg Schulenburg
+Copyright (C) GPLv2 2000-2013  Joerg Schulenburg
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -87,7 +87,8 @@ static void help(void) {
 	  "\tgocr -m 130 -p ./database/ text1.pbm  # extend database\n"
 	  "\tdjpeg -pnm -gray text.jpg | gocr -    # use jpeg-file via pipe\n"
 	  "\n");
-  fprintf(stderr, " webpage: http://jocr.sourceforge.net/\n");
+  fprintf(stderr, " webpage: http://jocr.sourceforge.net/ (may out of date)\n");
+  fprintf(stderr, " mirror:  http://www-e.uni-magdeburg.de/jschulen/ocr/\n");
   exit(0);
 }
 
@@ -318,20 +319,23 @@ void print_output(job_t *job) {
 
   assert(job);
         
+/* TODO: replace getTextLine-loop(line) by output_text() (libs have to use pipes)
+   simplify code 2010-09-26
+*/
   linecounter = 0;
-  line = getTextLine(linecounter++);
+  line = getTextLine(&(job->res.linelist), linecounter++);
   while (line) {
     /* notice: decode() is shiftet to getTextLine since 0.38 */
     fputs(line, stdout);
     if (job->cfg.out_format==HTML) fputs("<br />",stdout);
     if (job->cfg.out_format!=XML)  fputc('\n', stdout);
-    line = getTextLine(linecounter++);
+    line = getTextLine(&(job->res.linelist), linecounter++);
   }
-  free_textlines();
+  free_textlines(&(job->res.linelist));
 }
 
-/* FIXME jb: remove JOB; */
-job_t *JOB;
+/* FIXME jb: remove JOB; renamed to OCR_JOB 2010-09-26 */
+job_t *OCR_JOB;
 
 
 /* -------------------------------------------------------------
@@ -339,39 +343,40 @@ job_t *JOB;
 // ------------------------------------------------------------- */
 int main(int argn, char *argv[]) {
   int multipnm=1;
-  job_t job;
+  job_t job1, *job; /* fixme, dont want global variables for lib */
+  job=OCR_JOB=&job1;
 
-  JOB = &job;
   setvbuf(stdout, (char *) NULL, _IONBF, 0);	/* not buffered */
 
-  job_init(&job); /* init cfg and db */
+  job_init(job); /* init cfg and db */
 
-  process_arguments(&job, argn, argv);
+  process_arguments(job, argn, argv);
   
   /* load character data base (JS1002: now outside pgm2asc) */
-  if ( job.cfg.mode & 2 ) /* check for db-option flag */
-    load_db(); /* uses readpnm() and would conflict with multi images */
+  if ( job->cfg.mode & 2 ) /* check for db-option flag */
+    load_db(job);
+    /* load_db uses readpnm() and would conflict with multi images */
         
   while (multipnm==1) { /* multi-image loop */
 
-    job_init_image(&job); /* single image */
+    job_init_image(job); /* single image */
 
-    mark_start(&job);
+    mark_start(job);
 
-    multipnm = read_picture(&job);
+    multipnm = read_picture(job);
     /* separation of main and rest for using as lib
        this will be changed later => introduction of set_option()
        for better communication to the engine  */
     if (multipnm<0) break; /* read error */
   
     /* call main loop */
-    pgm2asc(&job);
+    pgm2asc(job);
 
-    mark_end(&job);
+    mark_end(job);
   
-    print_output(&job);
+    print_output(job);
 
-    job_free_image(&job);
+    job_free_image(job);
 
   }
 
