@@ -1,6 +1,6 @@
 /*
 This is a Optical-Character-Recognition program
-Copyright (C) 2000-2006  Joerg Schulenburg
+Copyright (C) 2000-2010  Joerg Schulenburg
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -21,31 +21,13 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "pgm2asc.h"
 #include "gocr.h"
 
-/* initialize job structure */
+/* initialize job structure cfg and db (for all images of a multiimage) */
 void job_init(job_t *job) {
   /* init source */
   job->src.fname = "-";
-  /* FIXME jb: init pix */  
-  job->src.p.p = NULL;
 
-  /* init results */
-  list_init( &job->res.boxlist );
-  list_init( &job->res.linelist ); 
-  job->res.avX = 5;
-  job->res.avY = 8; 
-  job->res.sumX = 0;
-  job->res.sumY = 0;
-  job->res.numC = 0;
-  job->res.lines.dy=0; 
-  job->res.lines.num=0;
-  
   /* init temporaries */
   list_init( &job->tmp.dblist ); 
-  job->tmp.n_run = 0;
-  /* FIXME jb: init ppo */
-  job->tmp.ppo.p = NULL; 
-  job->tmp.ppo.x = 0;
-  job->tmp.ppo.y = 0;
 
   /* init cfg */
   job->cfg.cs = 0;
@@ -62,8 +44,34 @@ void job_init(job_t *job) {
   job->cfg.unrec_marker = "_";
 }
 
+/* initialize job structure for every image (multi-images) */
+void job_init_image(job_t *job) {
+
+  /* FIXME jb: init pix */  
+  job->src.p.p = NULL;
+
+  /* init results */
+  list_init( &job->res.boxlist );
+  list_init( &job->res.linelist ); 
+  job->res.avX = 5;
+  job->res.avY = 8; 
+  job->res.sumX = 0;
+  job->res.sumY = 0;
+  job->res.numC = 0;
+  job->res.lines.dy=0; 
+  job->res.lines.num=0;
+  
+  /* init temporaries */
+  job->tmp.n_run = 0;
+  /* FIXME jb: init ppo */
+  job->tmp.ppo.p = NULL; 
+  job->tmp.ppo.x = 0;
+  job->tmp.ppo.y = 0;
+
+}
+
 /* free job structure */
-void job_free(job_t *job) {
+void job_free_image(job_t *job) {
 
   /* if tmp is just a copy of the pointer to the original image */
   if (job->tmp.ppo.p==job->src.p.p) job->tmp.ppo.p=NULL;
