@@ -35,7 +35,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "unicode_defs.h"
 
 /* only for debugging and development */
-#define IFV if(JOB->cfg.verbose&4)
+#define IFV if(OCR_JOB->cfg.verbose&4)
 #define MM {IFV fprintf(stderr,"\nDBG %c L%04d (%d,%d): ",(char)c_ask,__LINE__,box1->x0,box1->y0);}
 
 /* the old debug mode (0.40) was only for a special char, for another char
@@ -86,7 +86,7 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       DBG( char c_ask='5'; )
       if (sdata->holes.num > 1) Break; /* be tolerant */
       if( num_cross(  dx/2,  dx/2,0,dy-1,bp,cs)!=3
-      &&  num_cross(5*dx/8,3*dx/8,0,dy-1,bp,cs)!=3 ) Break;
+      &&  num_cross(6*dx/8,2*dx/8,0,dy-1,bp,cs)!=3 ) Break; // 2010-09-25 6x7
 
       i1=loop(bp,dx-1,dy-1,dx,cs,0,LE);
       i2=loop(bp,dx-1,dy-2,dx,cs,0,LE);
@@ -104,7 +104,7 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       // get the upper and lower hole koords, y around dy/4 ???
       x=5*dx/8;
       y  =loop(bp,x,0,dy,cs,0,DO); if(y>dy/8) Break;
-      y +=loop(bp,x,y,dy,cs,1,DO); if(y>dy/4) Break;
+      y +=loop(bp,x,y,dy,cs,1,DO); if(y>(dy+2)/4) Break; // 6x7 2010-09-25
       i1 =loop(bp,x,y,dy,cs,0,DO)+y; if(i1>5*dy/8) Break;
       i3=y=(y+i1)/2; // upper end can be shifted to the right for italic
       x  =loop(bp,0,y,dx,cs,0,RI); if(x>4*dx/8) Break;
@@ -198,7 +198,8 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       MSG(fprintf(stderr,"~S ad=%d",ad);)
 
       if ( gchar) ad=99*ad/100;
-      if (!hchar) ad=99*ad/100;
+      if (!hchar) ad=98*ad/100; // ~s 6x7 font tmp08/gocr0801_bad5.jpg
+      if (box1->m2 && y0>=box1->m2 && ad<100 && ad>96) {ad=96;MSG({})} // s
       Setac(box1,(wchar_t)'5',ad);
       if (ad==100) return '5';
       break;
@@ -215,18 +216,19 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       if( num_cross(0, dx-1,dy/2,dy/2,bp,cs) != 1 ) Break;
       if( num_cross(0, dx-1,dy-1,dy-1,bp,cs) != 1
        && num_cross(0, dx-1,dy-2,dy-2,bp,cs) != 1 ) Break;
-      /*  5x7  micr      ocr-a   6x10
-
+      /*  5x7  micr      ocr-a   6x10        6x9         bad 6x9 
+                                                         mozilla
           3x6  5x7       5x7      ..@@..<-
-                                  .@@@..
-                                  ..@@..
-               ooo        @@@..   ..@@..<
-          .$.  ooo        ..@..   ..@@..
-          $@.   oo        ..@..   ..@@..
-          .$.   oo        ..@..   ..@@..
-          .@.  ooooo      ..@.@   ..@@..
-          .$.  ooooo      ..@.@   ..@@..
-          $@$  ooooo      @@@@@   @@@@@@<-
+                                  .@@@..       @@@...<-   @@@...<- 
+                                  ..@@..       @.@...     ..@...   
+               ooo        @@@..   ..@@..<      ..@...     ..@...   
+          .$.  ooo        ..@..   ..@@..       ..@...<    ..@...<  
+          $@.   oo        ..@..   ..@@..       ..@...     ..@...   
+          .$.   oo        ..@..   ..@@..       ..@...     ..@...   
+          .@.  ooooo      ..@.@   ..@@..       ..@...     ..@...   
+          .$.  ooooo      ..@.@   ..@@..       ..@...     ..@...   
+          $@$  ooooo      @@@@@   @@@@@@<-     @@@@@@<-   @@@@@@<- 
+                                                        gocr0801_bad5
        */
       i4=0; // human font
       if (num_cross(0, dx-1,3*dy/4,3*dy/4,bp,cs) != 2 ) { // except ocr-a
@@ -298,9 +300,15 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       j =loop(bp,x,dy/2,dx,cs,1,RI); // thickness
       if( j>x+(dy+16)/32 ) ad=98*ad/100; // ~l but  MICR E-13B font
       x =loop(bp,0,0,dx,cs,0,RI); // straight line ???
-      j =loop(bp,0,1,dx,cs,0,RI);               if( j>x ) Break; // ~l
-      if( x==j ) j =loop(bp,0,dy/8,dx,cs,0,RI); if( j>x && !i4) Break;
-      if( x==j ) if(loop(bp,0,dy/4,dx,cs,0,RI)>x) {  // ~l
+      j =loop(bp,0,1,dx,cs,0,RI);
+      if (j>x) {
+        if (dy>9) { Break; }
+        else { if (ad>99) ad=ad*99/100; MSG({}) } // ~l but gocr0801_bad5
+      }
+      if (x==j) j =loop(bp,0,dy/8,dx,cs,0,RI);
+      if (j>x && y>9 && !i4) { Break; }
+      else if (j>x && !i4 && ad>99) { ad=ad*99/100; MSG({}) }
+      if (x==j) if(loop(bp,0,dy/4,dx,cs,0,RI)>x) {  // ~l
         // check micr-1 first before taken as 'l'
         if (loop(bp,dx-1,dy/8,dx,cs,0,LE)<=dx/4
          && loop(bp, 0,3*dy/4,dx,cs,1,RI)< dx-1) ad=97*ad/100;
@@ -352,7 +360,8 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
             loop(bp,0,dy/2-1,dx,cs,0,RI)>dx/4) ad=95*ad/100; // ~3
         if (loop(bp,dx-1,dy/2-1,dx,cs,0,LE)-
             loop(bp,dx-1,3*dy/4,dx,cs,0,LE)>dx/8) ad=99*ad/100; // ~3 ocr-a?
-        if (loop(bp,dx-1, dy/16,dx,cs,0,LE)-
+        if (loop(bp,dx-1, dy/4 ,dx,cs,0,LE)<dx/3  // 2010-09-25 6x9 
+         && loop(bp,dx-1, dy/16,dx,cs,0,LE)-
             loop(bp,dx-1,  dy/4,dx,cs,0,LE)>dx/8) ad=95*ad/100; // ~23
         MSG(fprintf(stderr,"23 check ad= %d", ad);)
       }
@@ -361,7 +370,8 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       if (i<=dy/4) {
         i+=loop(bp,dx-1-dx/8,dy-1-i,dy,cs,1,UP);
         if (i<=dy/4) {
-          i=loop(bp,dx-1-dx/8,dy-1-i,dy,cs,0,LE);
+          i=loop(bp,dx-1-dx/8,dy-1-i,dx,cs,0,LE);
+          if (loop(bp,dx-1,dy/4,dx,cs,0,LE)<dx/2) // 2010-09-25 6x9 1
           if (2*i>=dx && loop(bp,dx/4,0,dy,cs,0,DO)<dy/2) {
             if (dx<17) ad=98*ad/100;
             if (dx<9)  ad=97*ad/100;
@@ -369,6 +379,9 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
           }
         }
       }
+
+      // 2010-10-01 sample tmp10/barcode_code128_145      
+      if (dx<3 && dy>7 && box1->m4==0) ad=ad*96/100; // just a vertical line?
       
       // looking for  ###
       //              ..# pattern (its important, we dont want perp. lines as 1)
@@ -713,7 +726,7 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
    // --- test 4 --------------------------------------------------- 25Nov06
    for(ad=d=100;dy>3 && dx>2;){     // min 3x4 ~<gA',
      // rewritten for vectors 0.42
-      int ld, i1, i2, i3, i4, i5, i6, i7;  // line derivation + corners
+      int ld, i1, i2, i3, i4, i5, i6, i7, i2up;  // line derivation + corners
       DBG( wchar_t c_ask='4'; )
       if (sdata->holes.num > 1) Break; /* no or one hole */
       /* half distance to the center */
@@ -726,14 +739,16 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       }
       /* searching for 4 notches between neighbouring ends */
 
-/*
-    type A       B      C      D
-                     
-        1  5   1        1      1     
-        O  O   O       O5     O5
-        2OO3   O 5    O O    O O   <- 7 6
-           O   2O3O  2OO3   2OO3O
-           4     4      4      4
+/*                                       5x8 2010-10
+    type A       B      C      D            ...@.<-
+                                            ..@@.
+        1  5   1        1      1            .@.@.<
+        O  O   O       O5     O5            @..@.  left=i2up
+        2OO3   O 5    O O    O O   <- 7 6   @..@.
+           O   2O3O  2OO3   2OO3O           @@@@@
+           4     4      4      4            ...@.
+                                            ...@.<-
+                                         
            
      y4-y3 should be significant (bigger y3-y6)?
 */
@@ -745,6 +760,8 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       i1=nearest_frame_vector(box1, 0, i, x0, y0-dy);
       /* lowest from leftmost vector can be very low (20/23) */
       i2=nearest_frame_vector(box1, 0, i, x0-2*dx, (y0+7*y1)/8);
+      i2up=
+         nearest_frame_vector(box1, 0, i, x0-2*dx, (5*y0+3*y1)/8);
       /* lowest vector */
       i4=nearest_frame_vector(box1, 0, i, (x0+2*x1)/3, y1+dy);
       /* right center crossing point */     
@@ -784,7 +801,7 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
          || box1->frame_vector[i7][1]-y0>3*dy/4) ad=96*ad/100; // ~uU
       }
       // ToDo: output no=(x,y)
-      MSG(fprintf(stderr,"i1-7 %d %d %d %d %d %d %d",i1,i2,i3,i4,i5,i6,i7);)
+      MSG(fprintf(stderr,"i1-7 %d %d %d %d %d %d %d 2up %d",i1,i2,i3,i4,i5,i6,i7,i2up);)
       if (i5==i6) Break; // ~+
       
       if (box1->frame_vector[i1][1]>y0+dy/8) Break; // not to low
@@ -840,8 +857,11 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
              -box1->frame_vector[i2][1])>dy/4) Break;
       
       /* check if upper left and lower left points are joined directly */
-      ld=line_deviation(box1, i1, i2);
-      MSG(fprintf(stderr,"i1-i2 %d %d dist= %d/%d",i1,i2,ld,2*sq(1024/4));)
+      ld=line_deviation(box1, i1, i2up);
+      MSG(fprintf(stderr,"i1-i2up %d %d dist= %d/%d",i1,i2up,ld,2*sq(1024/4));)
+      if (ld >2*sq(1024/4)) Break;
+      if (i2!=i2up) ld=line_deviation(box1, i2up, i2); else  ld=0;
+      MSG(fprintf(stderr,"i2up-i2 %d %d dist= %d/%d",i2up,i2,ld,2*sq(1024/4));)
       if (ld >2*sq(1024/4)) Break;
       /* check if lower right and upper right points are joined directly */
       ld=line_deviation(box1, i2, i3);
@@ -1330,7 +1350,7 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
        if (!hchar) ad=98*ad/100; else // ~o
        if ( gchar) ad=99*ad/100;      // wrong line detection?
       } else { if (ad==100) ad=99; } /* not 100% sure */
-      if (ad>99) ad=99; /* we can never be sure having a O,
+      if (ad>98) ad=98; /* we can never be sure having a O, (2010-10 98%)
                            let context correction decide, see below! */
       Setac(box1,(wchar_t)'0',ad);
       break;
