@@ -70,7 +70,7 @@ otsu (unsigned char *image, int rows, int cols,
       int x0, int y0, int dx, int dy, int vvv) {
 
   unsigned char *np;    // pointer to position in the image we are working with
-  unsigned char op1, op2;   // predecessor of pixel *np (start value)
+  unsigned char op1, op2, op3, op4;   // predecessor of pixel *np (start value)
   int maxc=0;           // maximum contrast (start value) 
   int thresholdValue=1; // value we will threshold at
   int ihist[256];       // image histogram
@@ -83,7 +83,7 @@ otsu (unsigned char *image, int rows, int cols,
   // zero out histogram ...
   memset(ihist, 0, sizeof(ihist));
   memset(chist, 0, sizeof(chist));
-  op1=op2=0;
+  op4=op3=op1=op2=image[y0*cols+x0];
 
   gmin=255; gmax=0; k=dy/512+1;
   // v0.43 first get max contrast, dont do it together with next step
@@ -92,27 +92,38 @@ otsu (unsigned char *image, int rows, int cols,
     np = &image[(y0+i)*cols+x0];
     for (j = 0; j < dx ; j++) {
       ihist[*np]++;
-      if(*np > gmax) gmax=*np;
-      if(*np < gmin) gmin=*np;
+      if (*np > gmax) gmax=*np;
+      if (*np < gmin) gmin=*np;
       if (Abs(*np-op1)>maxc) maxc=Abs(*np-op1); /* new maximum contrast */
       if (Abs(*np-op2)>maxc) maxc=Abs(*np-op2); /* new maximum contrast */
+      // 2010-10-07 add op3+op4 for invalid_ogv.jpg
+      if (Abs(*np-op3)>maxc) maxc=Abs(*np-op3); /* new maximum contrast */
+      if (Abs(*np-op4)>maxc) maxc=Abs(*np-op4); /* new maximum contrast */
       /* we hope that maxc will be find its maximum very fast */
-      op2=op1;    /* shift old pixel to next older */
+      op4=op3;op3=op2;op2=op1;    /* shift old pixel to next older */
       op1=*np;     /* store old pixel for contrast check */
       np++;       /* next pixel */
     }
   }
+  if ((vvv&1)) // Debug
+    fprintf(stderr,"# threshold: max_contrast= %d\n", maxc);
 
   // generate the histogram
   // Aug06 images with large white or black homogeneous
   //   areas give bad results, so we only add pixels on contrast edges
+  op4=op3=op1=op2=image[y0*cols+x0];
   for (i =  0; i <  dy ; i+=k) {
     np = &image[(y0+i)*cols+x0];
     for (j = 0; j < dx ; j++) {
-      if (Abs(*np-op1)>maxc/4
-       || Abs(*np-op2)>maxc/4)
+      if (Abs(*np-op1)>=1*maxc/4 // min_d_max_contrast=1
+       || Abs(*np-op2)>=1*maxc/4 // min_d_max_contrast=2
+       || Abs(*np-op3)>=1*maxc/4
+       || Abs(*np-op4)>=1*maxc/4
+//       || Abs(*np-gmax)<=1*maxc/4
+//       || Abs(*np-gmin)<=1*maxc/4
+       )
          chist[*np]++; // count only relevant pixels
-      op2=op1;    /* shift old pixel to next older */
+      op4=op3;op3=op2;op2=op1;    /* shift old pixel to next older */
       op1=*np;     /* store old pixel for contrast check */
       np++;       /* next pixel */
     }
@@ -137,6 +148,11 @@ otsu (unsigned char *image, int rows, int cols,
     return (160);
   }
 
+  // ToDo: search max contrast in 2 near(r=8) pixels, take as mass centers + dist
+  //   expand b/w-mass ranges by further contrast dipols
+  //   min_max_b_b_distance + max_b_b distance
+  //  use a range white=... black=... for between values due local thresholding 
+  //  24x24 field (cashed) where 8x8 center is thresholded
   // ToDo: only care about extremas in a 3 pixel environment
   //       check if there are more than 2 mass centers (more colors)
   //       return object colors and color radius instead of threshold value
@@ -156,7 +172,7 @@ otsu (unsigned char *image, int rows, int cols,
   // do the otsu global thresholding method
 
   if ((vvv&1)) // Debug
-     fprintf(stderr,"# threshold: value ihist chist mass_dipol_moment\n");
+    fprintf(stderr,"# threshold: value ihist chist mass_dipol_moment trigg\n");
   fmax = -1.0;
   n1 = 0;
   for (k = 0; k < 255; k++) {
@@ -177,9 +193,10 @@ otsu (unsigned char *image, int rows, int cols,
       // thresholdValue = (m1 + 3 * m2) / 4;
     }
     if ((vvv&1) && ihist[k]) // Debug
-     fprintf(stderr,"# threshold: %3d %6d %6d %8.2f\n",
+     fprintf(stderr,"# threshold: %3d %6d %6d %8.3f %4d\n",
        k, ihist[k], chist[k],
-       sb/(dx*dy));  /* normalized dipol moment */
+       sb*256/(dx*dy)/(dx*dy),  /* normalized dipol moment */
+       thresholdValue);
   }
   // ToDo: error = left/right point where sb is 90% of maximum?
   // now we count all pixels for background detection
