@@ -23,7 +23,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "unicode.h"
 #include "output.h"
 #include "pcx.h"
-#include "gocr.h"  /* extern job_t JOB; */
+#include "gocr.h"  /* extern job_t OCR_JOB; */
 #include "unicode_defs.h" /* UNKNOWN + PICTURE */
 
 /* function is only for debugging and for developing
@@ -42,11 +42,11 @@ void out_b(struct box *px, pix *b, int x0, int y0, int dx, int dy, int cs ){
       x0=px->x0; dx=px->x1-px->x0+1;
       y0=px->y0; dy=px->y1-px->y0+1; yy0=y0;
     }
-    if(cs==0) cs=JOB->cfg.cs;
+    if(cs==0) cs=OCR_JOB->cfg.cs;
     fprintf(stderr,"\n# list box      x= %4d %4d d= %3d %3d r= %3d %3d"
                     " nrun=%d p=%p", /* ToDo: r,nrun is obsolete */
 	  px->x0, px->y0, px->x1 - px->x0 + 1, px->y1 - px->y0 + 1,
-	  px->x - px->x0, px->y - px->y0, JOB->tmp.n_run, (void*)px);
+	  px->x - px->x0, px->y - px->y0, OCR_JOB->tmp.n_run, (void*)px);
     fprintf(stderr,"\n#  dots=%d boxes=%d subboxes=%d c=%s mod=%s"
             " line=%d m= %d %d %d %d",
 	  px->dots, px->num_boxes, px->num_subboxes, 
@@ -133,7 +133,7 @@ void out_b(struct box *px, pix *b, int x0, int y0, int dx, int dy, int cs ){
 /* same as out_b, but for faster use, only a box as argument
  */
 void out_x(struct box *px) {
-  out_b(px,NULL,0, 0, 0, 0, JOB->cfg.cs);
+  out_b(px,NULL,0, 0, 0, 0, OCR_JOB->cfg.cs);
 }
 
 
@@ -141,7 +141,7 @@ void out_x(struct box *px) {
 void out_x2(struct box *box1, struct box *box2){
   int x,y,i,tx,ty,dy;
   /*FIXME jb static*/static char *c1="OXXXXxx@.,,,,,,,";
-  pix *b=&JOB->src.p;
+  pix *b=&OCR_JOB->src.p;
   dy=(box1->y1-box1->y0+1);
   if(dy<box2->y1-box2->y0+1)dy=box2->y1-box2->y0+1;
   tx=(box1->x1-box1->x0)/40+1;
@@ -150,11 +150,11 @@ void out_x2(struct box *box1, struct box *box2){
   for(i=0;i<dy;i+=ty) { /* reduce the output to max 78x40??? */
     fprintf(stderr,"\n"); y=box1->y0+i;
     for(x=box1->x0;x<=box1->x1;x+=tx) 
-    fprintf(stderr,"%c", c1[ ((getpixel(b,x,y)<JOB->cfg.cs)?0:8)+marked(b,x,y) ] );
+    fprintf(stderr,"%c", c1[ ((getpixel(b,x,y)<OCR_JOB->cfg.cs)?0:8)+marked(b,x,y) ] );
     if(!box2) continue;
     fprintf(stderr,"  "); y=box2->y0+i;
     for(x=box2->x0;x<=box2->x1;x+=tx)
-    fprintf(stderr,"%c", c1[ ((getpixel(b,x,y)<JOB->cfg.cs)?0:8)+marked(b,x,y) ] );
+    fprintf(stderr,"%c", c1[ ((getpixel(b,x,y)<OCR_JOB->cfg.cs)?0:8)+marked(b,x,y) ] );
   }
 }
 
@@ -169,8 +169,8 @@ int output_list(job_t *job) {
   char *lc = job->cfg.lc;
 
   fprintf(stderr,"\n# list shape for charlist %s",lc);
-  for_each_data(&(JOB->res.boxlist)) {
-    box2 = (struct box *) list_get_current(&(JOB->res.boxlist));
+  for_each_data(&(job->res.boxlist)) {
+    box2 = (struct box *) list_get_current(&(job->res.boxlist));
     for (j=0; j<box2->num_ac; j++) 
       if (!lc || (box2->tac[j] && strchr(lc, box2->tac[j]))
               || (box2->tas[j] && strstr(lc, box2->tas[j]))) break;
@@ -188,10 +188,10 @@ int output_list(job_t *job) {
 	      box2->num_frames, box2->num_ac, 
 	      (int)box2->c,   /* wchar_t -> char ???? */
 	      decode(box2->c,ASCII) );
-      if (JOB->cfg.verbose & 4) out_x(box2);
+      if (job->cfg.verbose & 4) out_x(box2);
     }
     i++;
-  } end_for_each(&(JOB->res.boxlist));
+  } end_for_each(&(job->res.boxlist));
   fprintf(stderr,"\n");
   return 0;
 }
