@@ -28,10 +28,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 /* measure mean thickness as an criteria for big chars */
 int mean_thickness( struct box *box2 ){
-  int mt=0, i, y, dx=box2->x1-box2->x0+1, dy;
+  int mt=0, i, y, dx=box2->x1-box2->x0+1, dy, cs=OCR_JOB->cfg.cs;
   for (y=box2->y0+1; y<box2->y1; y++) {
-    i=loop(box2->p,box2->x0+0,y,dx,JOB->cfg.cs,0,RI);
-    i=loop(box2->p,box2->x0+i,y,dx,JOB->cfg.cs,1,RI);
+    i=loop(box2->p,box2->x0+0,y,dx,cs,0,RI);
+    i=loop(box2->p,box2->x0+i,y,dx,cs,1,RI);
     mt+=i;
   } 
   dy = box2->y1 - box2->y0 - 1; 
@@ -69,7 +69,8 @@ int remove_dust( job_t *job ){
   for_each_data(&(job->res.boxlist)) {
     box2 = (struct box *)list_get_current(&(job->res.boxlist));
     if (!box2->num_frames) continue;
-    if (box2->frame_vol[0]<0) continue; /* don't count inner holes */
+    // bad for big fonts 2010-10 invalid_ogv
+    // if (box2->frame_vol[0]<0) continue; /* don't count inner holes */
     j = abs(box2->frame_vol[0]);
     if ((box2->y1-box2->y0+1)>3) {
        nC++; /* only count potential chars v0.42 */
@@ -87,15 +88,16 @@ int remove_dust( job_t *job ){
      */
     job->cfg.dust_size = (  ( sX/nC ) * ( sY/nC ) + 16) / 32; // maximum
     if (sY/nC<10) job->cfg.dust_size=1; // 2010-09-24 6x9 gocr0801_bad5_FP 
-    if (vvv) fprintf(stderr, "# remove.c remove_dust(): ");
-    if (vvv) fprintf(stderr, "\n# dust size detection, vol num"
-      " obj=%d maxDust=%d mpixel= %3d mxy= %2d %2d",
+    if (vvv) fprintf(stderr, "# remove.c remove_dust():");
+    if (vvv) fprintf(stderr, "\n#  dust size detection, vol num"
+      " obj=%d maxDust=%d mP= %3d mXY= %2d %2d",
       nC, job->cfg.dust_size, sP/nC, sX/nC, sY/nC);
     /* we assume that for random dust applies histo[i+1]<histo[i] */
     for (i=1;i+3<HISTSIZE;i++){
-      if (vvv) fprintf(stderr,"\n# dust size histogram %3d %5d",i,histo[i]);
+      if (vvv) fprintf(stderr,"\n#  dust size histogram %3d %5d",i,histo[i]);
       if (histo[i]>=nC) continue; /* v0.42 lot of pixels -> bg pattern < 3 */
       if (i>=job->cfg.dust_size) break;   /* maximum = mean size / 32 */
+      if (i<job->cfg.dust_size/16 && i<9) continue; /* giant font? tmp10/invalid_olv 2010-10 */
       if (histo[i/*+1*/]==0) break;           /* bad statistic */
       if ((histo[i+2]+histo[i+3])
         >=(histo[i]  +histo[i+1])) break;  /* no noise, but to late? */
@@ -106,7 +108,7 @@ int remove_dust( job_t *job ){
     if (vvv) for (i1=0,j=i+1;j<HISTSIZE;j++) {
       /* compressed, output only if something is changing */
       if (j==HISTSIZE-1 || histo[j]!=histo[j-1] || histo[j]!=histo[j+1]) {
-        fprintf(stderr,"\n# dust size histogram %3d %5d",j,histo[j]);
+        fprintf(stderr,"\n#  dust size histogram %3d %5d",j,histo[j]);
         if (++i1>20) break; /* dont do excessive output */
       }
     }
@@ -118,7 +120,7 @@ int remove_dust( job_t *job ){
      *    (p/(x*y))^2 * (x*y) = p^2/(x*y) doublets and
      *    (p/(x*y))^3 * (x*y) = p^3/(x*y)^2 triplets
      */
-    if (vvv) fprintf(stderr,"\n# auto dust size = %d nC= %3d .. %3d"
+    if (vvv) fprintf(stderr,"\n#  auto dust size = %d nC= %3d .. %3d"
                             " avD= %2d %2d .. %2d %2d\n",
                    job->cfg.dust_size, nC, job->res.numC,
            (job->res.sumX+job->res.numC/2)/job->res.numC,
@@ -127,7 +129,7 @@ int remove_dust( job_t *job ){
   if (job->cfg.dust_size)
   { i=0;
     if(vvv){
-       fprintf(stderr,"# remove dust of size %2d",job->cfg.dust_size);
+       fprintf(stderr,"#  remove dust of size %2d",job->cfg.dust_size);
        /* Warning: better use (1/(x*y))^2 as 1/((x*y)^2),
         * because (x*y)^2 may overflow */
        fprintf(stderr," histo=%d,%d(?=%d),%d(?=%d),...\n# ...",
@@ -191,7 +193,7 @@ int remove_dust( job_t *job ){
   return 0;
 }
 
-/* ---- smooth big chars ---------------------------------
+/* ---- smooth borders ---------------------------------
  * Big chars often do not have smooth borders, which let fail
  * the engine. Here we smooth the borders of big chars (>7x16).
  * Smoothing is important for b/w scans, where we often have
@@ -205,7 +207,7 @@ int smooth_borders( job_t *job ){
         cn[8],cm,vvv=job->cfg.verbose; /* dust found */
     struct box *box2;
     cs=job->cfg.cs; n1=n2=0;
-    if(vvv){ fprintf(stderr,"# smooth big chars 7x16 cs=%d",cs); }
+    if(vvv){ fprintf(stderr,"# smooth_borders of big chars 7x16 cs=%d",cs); }
     /* filter for each big box */
     for_each_data(&(job->res.boxlist)) { n2++; /* count boxes */
         box2 = (struct box *)list_get_current(&(job->res.boxlist));
@@ -468,21 +470,22 @@ int remove_pictures( job_t *job){
         j1       j2      j3
   - can generate new boxes if two characters were glued
   */
-int remove_melted_serifs( pix *pp ){
-  int x,y,j1,j2,j3,j4,i2,i3,i,ii,ni,cs,x0,x1,xa,xb,y0,y1,vvv=JOB->cfg.verbose;
+int remove_melted_serifs( job_t *job, pix *pp ){
+  int x,y,j1,j2,j3,j4,i2,i3,i,ii,ni,cs,x0,x1,xa,xb,y0,y1,vvv;
   struct box *box2, *box3;
+  // job_t *job=OCR_JOB;
   progress_counter_t *pc = NULL;
 
-  cs=JOB->cfg.cs; i=0; ii=0; ni=0;
-  for_each_data(&(JOB->res.boxlist)) {
+  vvv=job->cfg.verbose; cs=job->cfg.cs; i=0; ii=0; ni=0;
+  for_each_data(&(job->res.boxlist)) {
     ni++; 
-  } end_for_each(&(JOB->res.boxlist));
+  } end_for_each(&(job->res.boxlist));
   pc = open_progress(ni,"remove_melted_serifs");
   ni = 0;
 
   if(vvv){ fprintf(stderr,"# searching melted serifs ..."); }
-  for_each_data(&(JOB->res.boxlist)) {
-    box2 = (struct box *)list_get_current(&(JOB->res.boxlist));
+  for_each_data(&(job->res.boxlist)) {
+    box2 = (struct box *)list_get_current(&(job->res.boxlist));
     if (box2->c != UNKNOWN) continue; /* dont try on pictures */
     x0=box2->x0; x1=box2->x1; 
     y0=box2->y0; y1=box2->y1;	/* box */
@@ -500,7 +503,7 @@ int remove_melted_serifs( pix *pp ){
       } if(j3==0){ j1+=x; continue; }   /* no serif, skip this object */
       y = y0+(j2+j3-1)/j3+(y1-y0+1)/32; /* y0 + mean thickness + dy/32 + 1 */
       if (vvv&1)
-        fprintf(stderr, "\n#  upper serif x0,y0,j1-x0+x,y-y0 %4d %4d %2d+%2d %2d",
+        fprintf(stderr, "\n#  upper serif x0,y0,j1-x0+x,y-y0 %4d %4d %3d + %2d %2d",
           x0,y0,j1-x0,x,y-y0);
 
       /* check if really melted serifs */
@@ -548,8 +551,9 @@ int remove_melted_serifs( pix *pp ){
 	  box2->x0=j2+1; x1=box2->x1;
 	  cut_box(box2); /* cut vectors outside the box, see box.c */
 	  cut_box(box3);
-	  box3->num=JOB->res.numC;
-	  list_ins(&(JOB->res.boxlist),box2,box3); JOB->res.numC++; ii++; /* insert box3 before box2 */
+	  box3->num=job->res.numC;
+	  list_ins(&(job->res.boxlist),box2,box3);
+	  job->res.numC++; ii++; /* insert box3 before box2 */
 	  if(vvv&4) fprintf(stderr," => splitted");
 	  j1=x0=box2->x0; x=0; /* hopefully ok, UVW */
 	}
@@ -575,7 +579,7 @@ int remove_melted_serifs( pix *pp ){
       } if(j3==0){ j1+=x; continue; } 
       y = y1-(j2+j3-1)/j3-(y1-y0+1)/32;
       if (vvv&1)
-        fprintf(stderr, "\n#  lower serif x0,y0,j1-x0+x,y1-y %4d %4d %2d+%2d %2d",
+        fprintf(stderr, "\n#  lower serif x0,y0,j1-x0+x,y1-y %4d %4d %3d + %2d %2d",
           x0,y0,j1-x0,x,y1-y);
 
       /* check if really melted serifs */
@@ -618,8 +622,8 @@ int remove_melted_serifs( pix *pp ){
 	  box2->x0=j2; x1=box2->x1;
 	  cut_box(box2); /* cut vectors outside the box */
 	  cut_box(box3);
-	  box3->num=JOB->res.numC;
-	  list_ins(&(JOB->res.boxlist),box2,box3); JOB->res.numC++; ii++;
+	  box3->num=job->res.numC;
+	  list_ins(&(job->res.boxlist),box2,box3); job->res.numC++; ii++;
 	  /* box3,box2 in correct order??? */
 	  if(vvv&4) fprintf(stderr," => splitted");
 	  j1=x0=box2->x0; x=0; /* hopefully ok, NMK */
@@ -628,7 +632,7 @@ int remove_melted_serifs( pix *pp ){
       j1+=x;
     }
     progress(ni++,pc);
-  } end_for_each(&(JOB->res.boxlist));
+  } end_for_each(&(job->res.boxlist));
   close_progress(pc);
   if(vvv)fprintf(stderr," %3d cluster corrected, %d new boxes\n",i,ii);
   return 0;
@@ -637,42 +641,46 @@ int remove_melted_serifs( pix *pp ){
 /*  remove black borders often seen on bad scanned copies of books
     - dust around the border
  */
-int remove_rest_of_dust() {
-  int i1, i2, vvv = JOB->cfg.verbose, x0, x1, y0, y1, cnt=0;
+int remove_rest_of_dust( job_t *job ) {
+  //  job_t *job=OCR_JOB;
+  int i1, i2, vvv = job->cfg.verbose, x0, x1, y0, y1, cnt=0;
   struct box *box2, *box4;
   progress_counter_t *pc = NULL;
   
   i1 = i2 = 0; /* counter for removed boxes */
   if (vvv)
-    fprintf(stderr, "# detect dust (avX,nC), ... ");
+    fprintf(stderr, "# remove_rest_of_dust (avX,nC), ... ");
   /* remove fragments from border */
-  for_each_data(&(JOB->res.boxlist)) {
-    box2 = (struct box *)list_get_current(&(JOB->res.boxlist));
+  for_each_data(&(job->res.boxlist)) {
+    box2 = (struct box *)list_get_current(&(job->res.boxlist));
     if (box2->c == UNKNOWN) {
       x0 = box2->x0; x1 = box2->x1;
       y0 = box2->y0; y1 = box2->y1;	/* box */
       /* box in char ??? */
-      if (  2 * JOB->res.numC * (y1 - y0 + 1) < 3 * JOB->res.sumY
+      if (  2 * job->res.numC * (y1 - y0 + 1) < 3 * job->res.sumY
         && ( y1 < box2->p->y/4 || y0 > 3*box2->p->y/4 )  /* not single line */
-        && JOB->res.numC > 1		/* do not remove everything */
+        && job->res.numC > 1		/* do not remove everything */
         && ( box2->m4 == 0 ) )	/* remove this */
       {
-	 JOB->res.numC--; /* ToDo: dont count tiny pixels */
+	 job->res.numC--; /* ToDo: dont count tiny pixels */
 	 /* ToDo: res.sumX,Y must also be corrected */
 	 i1++;
-	 list_del(&(JOB->res.boxlist), box2);
+	 list_del(&(job->res.boxlist), box2);
 	 free_box(box2);
+	 if (vvv) fprintf(stderr,"\n#  remove1 %3d %3d ", x0, y0);
       }
     }
-  } end_for_each(&(JOB->res.boxlist));
+  } end_for_each(&(job->res.boxlist));
 
-  pc = open_progress(JOB->res.boxlist.n,"remove_dust2");
-  for_each_data(&(JOB->res.boxlist)) {
-    box2 = (struct box *)list_get_current(&(JOB->res.boxlist));
+  pc = open_progress(job->res.boxlist.n,"remove_dust2");
+  for_each_data(&(job->res.boxlist)) {
+    box2 = (struct box *)list_get_current(&(job->res.boxlist));
     progress(cnt++,pc);
     if (box2->c == PICTURE) continue;
     x0 = box2->x0; x1 = box2->x1;
     y0 = box2->y0; y1 = box2->y1;	/* box */
+    if (box2->m2 && 4*y0>box2->m2+3*box2->m3 && 2*y1<box2->m3+box2->m4)
+      continue; // dont remove . 2010-10-09 qemu
     /* remove tiny box2 if to far away from bigger boxes */
     /* ToDo: remove clouds of tiny pixels (count near small, compare with num bigger) */
     /* 0.42: remove far away pixel? ToDo: do it at earlier? */
@@ -680,8 +688,8 @@ int remove_rest_of_dust() {
       int xn, yn, xs, ys;
       int found=0;  /* nearest bigger box */
       /* search near bigger box */
-      for_each_data(&(JOB->res.boxlist)) {
-        box4 = (struct box *)list_get_current(&(JOB->res.boxlist));
+      for_each_data(&(job->res.boxlist)) {
+        box4 = (struct box *)list_get_current(&(job->res.boxlist));
         if (found || box4 == box2) continue; 
         if (box4->x1-box4->x0+1<3 && box4->y1-box4->y0+1<3) continue;
         xs =  box4->x1-box4->x0+1;
@@ -689,18 +697,19 @@ int remove_rest_of_dust() {
         xn = abs((box4->x0+box4->x1)/2 - box2->x0);
         yn = abs((box4->y0+box4->y1)/2 - box2->y0);
         if (2*xn < 3*xs && 2*yn < 3*ys) { found=1; }
-      } end_for_each(&(JOB->res.boxlist));
+      } end_for_each(&(job->res.boxlist));
       if (!found) { /* found nothing, box2 to far from big boxes */
         i2++;
-        list_del(&(JOB->res.boxlist), box2);
+        list_del(&(job->res.boxlist), box2);
         free_box(box2);
+	 if (vvv) fprintf(stderr,"\n#  remove2 %3d %3d ", x0, y0);
       }
     }
-  } end_for_each(&(JOB->res.boxlist));
+  } end_for_each(&(job->res.boxlist));
   close_progress(pc);
   if (vvv)
     fprintf(stderr, " %3d + %3d boxes deleted, nC= %d ?\n",
-            i1, i2, JOB->res.numC);
+            i1, i2, job->res.numC);
 
   return 0;
 }
