@@ -514,7 +514,7 @@ const char *decode(wchar_t c, FORMAT type) {
 	  case '}':
 	      return (const char *)"\\}";
 	  case '\\':
-	      return (const char *)"$\\backslash$";
+	      return (const char *)"\\textbackslash";
 	  case '~':
 	      return (const char *)"\\~{}";
 	  case '^':
